"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const levelup_1 = __importDefault(require("levelup"));
const leveldown_1 = __importDefault(require("leveldown"));
const encoding_down_1 = __importDefault(require("encoding-down"));
const path_1 = require("path");
const datastore_methods_1 = require("./datastore.methods");
const get_operation_1 = require("../operations/get.operation");
const push_operation_1 = require("../operations/push.operation");
const edit_operation_1 = require("../operations/edit.operation");
const delete_operation_1 = require("../operations/delete.operation");
class Datastore {
    constructor(name, directory, type) {
        this.name = name;
        const encoding = encoding_down_1.default(leveldown_1.default(path_1.join(directory, name)), { valueEncoding: 'json' });
        this.store = levelup_1.default(encoding);
        this.type = type();
        this.methods = new datastore_methods_1.DatastoreOperations(() => this, this.store, type);
    }
    create(data) {
        data.setDb(this);
        return data;
    }
    push() {
        return new push_operation_1.PushOperation(this);
    }
    pushBatched() {
        return new push_operation_1.BatchedPushOperation(this);
    }
    get() {
        return new get_operation_1.GetOperation(this);
    }
    edit() {
        return new edit_operation_1.EditOperation(this);
    }
    delete() {
        return new delete_operation_1.DeleteOperation(this);
    }
    deleteBatched() {
        return new delete_operation_1.BatchedDeleteOperation(this);
    }
}
exports.Datastore = Datastore;
//# sourceMappingURL=datastore.js.map